==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/GeographicContourLineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ValueBrushScaleDescriptionMetadata } from "./ValueBrushScaleDescriptionMetadata";
import { ContourValueResolverDescriptionMetadata } from "./ContourValueResolverDescriptionMetadata";
import { TriangulationStatusEventArgsDescriptionMetadata } from "./TriangulationStatusEventArgsDescriptionMetadata";
import { GeographicXYTriangulatingSeriesDescriptionMetadata } from "./GeographicXYTriangulatingSeriesDescriptionMetadata";
import { GeographicContourLineSeriesDescription } from "./GeographicContourLineSeriesDescription";
/**
 * @hidden
 */
var GeographicContourLineSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicContourLineSeriesDescriptionMetadata, _super);
    function GeographicContourLineSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicContourLineSeriesDescriptionMetadata.b = function (a) {
        if (GeographicContourLineSeriesDescriptionMetadata.a == null) {
            GeographicContourLineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicContourLineSeriesDescriptionMetadata.c(GeographicContourLineSeriesDescriptionMetadata.a);
        }
        if (a.g(GeographicContourLineSeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(GeographicContourLineSeriesDescriptionMetadata.a);
        ValueBrushScaleDescriptionMetadata.d(a);
        ContourValueResolverDescriptionMetadata.d(a);
        TriangulationStatusEventArgsDescriptionMetadata.d(a);
    };
    GeographicContourLineSeriesDescriptionMetadata.c = function (a) {
        GeographicXYTriangulatingSeriesDescriptionMetadata.c(a);
        a.item("ValueMemberPath", "String");
        a.item("FillScale", "ExportedType:ValueBrushScale");
        a.item("ActualFillScale", "ExportedType:ValueBrushScale");
        a.item("ValueResolver", "ExportedType:ContourValueResolver");
        a.item("TriangulationStatusChangedRef", "EventRef::triangulationStatusChanged");
    };
    GeographicContourLineSeriesDescriptionMetadata.d = function (a) {
        GeographicContourLineSeriesDescriptionMetadata.b(a);
        a.u("GeographicContourLineSeries", function () { return new GeographicContourLineSeriesDescription(); });
        a.t("GeographicContourLineSeries", GeographicContourLineSeriesDescriptionMetadata.a);
    };
    GeographicContourLineSeriesDescriptionMetadata.$t = markType(GeographicContourLineSeriesDescriptionMetadata, 'GeographicContourLineSeriesDescriptionMetadata');
    GeographicContourLineSeriesDescriptionMetadata.a = null;
    return GeographicContourLineSeriesDescriptionMetadata;
}(Base));
export { GeographicContourLineSeriesDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GeographicContourLineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ValueBrushScaleDescriptionMetadata } from "./ValueBrushScaleDescriptionMetadata";
import { ContourValueResolverDescriptionMetadata } from "./ContourValueResolverDescriptionMetadata";
import { TriangulationStatusEventArgsDescriptionMetadata } from "./TriangulationStatusEventArgsDescriptionMetadata";
import { GeographicXYTriangulatingSeriesDescriptionMetadata } from "./GeographicXYTriangulatingSeriesDescriptionMetadata";
import { GeographicContourLineSeriesDescription } from "./GeographicContourLineSeriesDescription";
/**
 * @hidden
 */
var GeographicContourLineSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicContourLineSeriesDescriptionMetadata, _super);
    function GeographicContourLineSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicContourLineSeriesDescriptionMetadata.b = function (a) {
        if (GeographicContourLineSeriesDescriptionMetadata.a == null) {
            GeographicContourLineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicContourLineSeriesDescriptionMetadata.c(GeographicContourLineSeriesDescriptionMetadata.a);
        }
        if (a.j(GeographicContourLineSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(GeographicContourLineSeriesDescriptionMetadata.a);
        ValueBrushScaleDescriptionMetadata.d(a);
        ContourValueResolverDescriptionMetadata.d(a);
        TriangulationStatusEventArgsDescriptionMetadata.d(a);
    };
    GeographicContourLineSeriesDescriptionMetadata.c = function (a) {
        GeographicXYTriangulatingSeriesDescriptionMetadata.c(a);
        a.item("ValueMemberPath", "String");
        a.item("FillScale", "ExportedType:ValueBrushScale");
        a.item("ActualFillScale", "ExportedType:ValueBrushScale");
        a.item("ValueResolver", "ExportedType:ContourValueResolver");
        a.item("TriangulationStatusChangedRef", "EventRef::triangulationStatusChanged");
    };
    GeographicContourLineSeriesDescriptionMetadata.d = function (a) {
        GeographicContourLineSeriesDescriptionMetadata.b(a);
        a.aa("GeographicContourLineSeries", function () { return new GeographicContourLineSeriesDescription(); });
        a.z("GeographicContourLineSeries", GeographicContourLineSeriesDescriptionMetadata.a);
    };
    GeographicContourLineSeriesDescriptionMetadata.$t = markType(GeographicContourLineSeriesDescriptionMetadata, 'GeographicContourLineSeriesDescriptionMetadata');
    GeographicContourLineSeriesDescriptionMetadata.a = null;
    return GeographicContourLineSeriesDescriptionMetadata;
}(Base));
export { GeographicContourLineSeriesDescriptionMetadata };
